==> keepassx_0.2.2.orig.tar.gz: keepassx-0.2.2/src/export/Export_Txt.h <==
/***************************************************************************
 *   Copyright (C) 2005-2006 by Tarek Saidi                                 *
 *   tarek.saidi@arcor.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _EXPORT_TXT_H_
#define _EXPORT_TXT_H_
#include <QObject>
#include "PwManager.h"

class Export_Txt:public QObject{
public:
	bool exportFile(const QString& filename,Database* db,QString& err);

};

#endif

==> keepassx_0.4.3.orig.tar.gz: keepassx-0.4.3/src/export/Export_Txt.h <==
/***************************************************************************
 *   Copyright (C) 2005-2007 by Tarek Saidi                                *
 *   tarek.saidi@arcor.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *

 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _EXPORT_TXT_H_
#define _EXPORT_TXT_H_

#include "Export.h"

class Export_Txt:public ExporterBase, public IExport{
	Q_OBJECT
	
	public:
		virtual bool exportDatabase(QWidget* GuiParent, IDatabase* Database);	
		virtual QString identifier(){return "e_txt";}
		virtual QString title(){return tr("Text File");}
};

#endif
